---
name: Feature request
about: Suggest an idea on how to improve Rasa
title: ''
labels: enhancement
assignees: ''

---

**Description of Problem**:
<!-- Short overview of the current situation.
Why is this feature needed? Please link any relevant
[forum](https://forum.rasa.com) threads here. -->

**Overview of the Solution**:
<!-- What would a possible solution look like?
Describe, without going too low into technical details,
what changes need to happen during implementation of this feature. -->

**Examples** (if relevant):
<!-- List examples and/or link to relevant references. -->

**Blockers** (if relevant):
<!-- Is this feature blocked by anything or anyone?
Or might there be any potential blockers on the way? -->

**Definition of Done**:
<!-- What needs to be there to consider this feature as done?
- [ ] Tests are added
- [ ] Feature described the docs
- [ ] Feature mentioned in the changlog
- [ ] ... -->
